@@ -31,7 +31,7 @@
 
     enchant.checker:  High-level spellchecking functionality
     
-    This package is designed to host higer-level spellchecking functionality
+    This package is designed to host higher-level spellchecking functionality
     than is available in the base enchant package.  It should make writing
     applications that follow common usage idioms significantly easier.
     
@@ -46,6 +46,7 @@
 
 import array
 import unittest
+import warnings
 
 import enchant
 import enchant.tokenize
@@ -54,7 +55,7 @@ from enchant.tokenize import get_tokenizer
 from enchant.utils import bytes, unicode, raw_unicode, basestring
 
 class SpellChecker:
-    """Class implementing stateful spellchecking behavior.
+    """Class implementing stateful spellchecking behaviour.
         
     This class is designed to implement a spell-checking loop over
     a block of text, correcting/ignoring/replacing words as required.
@@ -97,13 +98,15 @@ class SpellChecker:
     
     If using an array of characters with this object and the
     array is modified outside of the spellchecking loop, use the
-    'set_offet' method to reposition the internal loop pointer
-    to make sure it doesnt skip any words.
+    'set_offset' method to reposition the internal loop pointer
+    to make sure it doesn't skip any words.
     
     """
+    _DOC_ERRORS = ["sme","fw","speling","chkr","chkr","chkr"]
     
     def __init__(self,lang,text=None,tokenize=None,filters=None):
         """Constructor for the SpellChecker class.
+
         SpellChecker objects can be created in two ways, depending on
         the nature of the first argument.  If it is a string, it
         specifies a language tag from which a dictionary is created.
@@ -143,7 +146,7 @@ class SpellChecker:
         # Default to the empty string as the text to be checked
         self._text = array.array('u')
         self._use_tostring = False
-        self._tokens = ()
+        self._tokens = iter([])
         
         if text is not None:
             self.set_text(text)
@@ -154,6 +157,7 @@ class SpellChecker:
         
     def set_text(self,text):
         """Set the text to be spell-checked.
+
         This method must be called, or the 'text' argument supplied
         to the constructor, before calling the 'next()' method.
         """
@@ -183,6 +187,7 @@ class SpellChecker:
 
     def wants_unicode(self):
         """Check whether the checker wants unicode strings.
+
         This method will return True if the checker wants unicode strings
         as input, False if it wants normal strings.  It's important to
         provide the correct type of string to the checker.
@@ -193,9 +198,10 @@ class SpellChecker:
 
     def coerce_string(self,text,enc=None):
         """Coerce string into the required type.
+
         This method can be used to automatically ensure that strings
         are of the correct type required by this checker - either unicode
-        or standard.  If there is a mis-match, conversion is done using
+        or standard.  If there is a mismatch, conversion is done using
         python's default encoding unless another encoding is specified.
         """
         if self.wants_unicode():
@@ -224,7 +230,7 @@ class SpellChecker:
         are found, it will raise StopIteration.
         
         The method will always return self, so that it can be used
-        sensibly in common idoms such as:
+        sensibly in common idioms such as:
 
             for err in checker:
                 err.do_something()
@@ -259,7 +265,8 @@ class SpellChecker:
     
     def replace_always(self,word,repl=None):
         """Always replace given word with given replacement.
-        If a single argumet is given, this is used to replace the
+
+        If a single argument is given, this is used to replace the
         current erroneous word.  If two arguments are given, that
         combination is added to the list for future use.
         """
@@ -274,6 +281,7 @@ class SpellChecker:
 
     def ignore_always(self,word=None):
         """Add given word to list of words to ignore.
+
         If no word is given, the current erroneous word is added.
         """
         if word is None:
@@ -284,14 +292,24 @@ class SpellChecker:
             
     def add_to_personal(self,word=None):
         """Add given word to the personal word list.
+
+        If no word is given, the current erroneous word is added.
+        """
+        warnings.warn("SpellChecker.add_to_personal is deprecated, please use SpellChecker.add",category=DeprecationWarning)
+        self.add(word)
+
+    def add(self,word=None):
+        """Add given word to the personal word list.
+
         If no word is given, the current erroneous word is added.
         """
         if word is None:
             word = self.word
-        self.dict.add_to_personal(word)
+        self.dict.add(word)
     
     def suggest(self,word=None):
         """Return suggested spellings for the given word.
+
         If no word is given, the current erroneous word is used.
         """
         if word is None:
@@ -304,8 +322,9 @@ class SpellChecker:
         return self.dict.check(word)
 
     def set_offset(self,off,whence=0):
-        """Set the offset of the tokenisation routine.
-        For more details on the purpose of the tokenisation offset,
+        """Set the offset of the tokenization routine.
+
+        For more details on the purpose of the tokenization offset,
         see the documentation of the 'enchant.tokenize' module.
         The optional argument whence indicates the method by
         which to change the offset:
@@ -326,6 +345,7 @@ class SpellChecker:
     
     def leading_context(self,chars):
         """Get <chars> characters of leading context.
+
         This method returns up to <chars> characters of leading
         context - the text that occurs in the string immediately
         before the current erroneous word.
@@ -336,6 +356,7 @@ class SpellChecker:
     
     def trailing_context(self,chars):
         """Get <chars> characters of trailing context.
+
         This method returns up to <chars> characters of trailing
         context - the text that occurs in the string immediately
         after the current erroneous word.
@@ -347,7 +368,7 @@ class SpellChecker:
         
             
 class TestChecker(unittest.TestCase):
-    """TestCases for checking behavior of SpellChecker class."""
+    """TestCases for checking behaviour of SpellChecker class."""
     
     def test_basic(self):
         """Test a basic run of the SpellChecker class."""
@@ -436,6 +457,7 @@ class TestChecker(unittest.TestCase):
 
     def test_chararray(self):
         """Test SpellChecker with a character array as input."""
+        # Python 3 does not provide 'c' array type
         if str is unicode:
            atype = 'u'
         else:
@@ -460,3 +482,28 @@ class TestChecker(unittest.TestCase):
         else:
           self.assertEqual(txtarr.tostring(),"I wll be stored in an array")
 
+    def test_pwl(self):
+        """Test checker loop with PWL."""
+        from enchant import DictWithPWL
+        d = DictWithPWL("en_US",None,None)
+        txt = "I am sme text to be cheked with personal list of cheked words"
+        chkr = SpellChecker(d,txt)
+        for n,err in enumerate(chkr):
+            if n == 0:
+                self.assertEqual(err.word,"sme")
+            if n == 1:
+                self.assertEqual(err.word,"cheked")
+                chkr.add()
+        self.assertEqual(n,1)
+
+    def test_bug2785373(self):
+        """Testcases for bug #2785373."""
+        c = SpellChecker(enchant.Dict("en"),"")
+        c.set_text("So, one dey when I wes 17, I left.")
+        for err in c:
+            pass
+        c = SpellChecker(enchant.Dict("en"),"")
+        c.set_text(raw_unicode("So, one dey when I wes 17, I left."))
+        for err in c:
+            pass
+ 
