@@ -137,6 +137,7 @@ class Trie:
             pass
         # All done!
         return res
+    search._DOC_ERRORS = ["nerrs"]
         
     def __getitem__(self,key):
         return self._keys[key]
@@ -259,6 +260,7 @@ class PyPWL:
         """
         # Too much work for this simple spellchecker
         pass
+    store_replacement._DOC_ERRORS = ["mis","mis"]
 
     def is_added(self,word):
         """Check whether a word is in the personal word list."""
